package ru.redguy.dynamicshop.api;

import org.bukkit.configuration.InvalidConfigurationException;
import org.bukkit.configuration.file.YamlConfiguration;
import org.jetbrains.annotations.Nullable;
import ru.redguy.dynamicshop.DynamicShop;

import java.io.File;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;

public class Database {
    private static final Database instance = new Database();

    public static Database getInstance() {
        return instance;
    }

    private final File file = new File(DynamicShop.getInstance().getDataFolder(), "items.yml");
    private final YamlConfiguration conf = new YamlConfiguration();

    public Database() {
        load();
        save();
    }

    public void load() {
        try {
            conf.load(file);
        } catch (FileNotFoundException e) {
            try {
                file.createNewFile();
            } catch (IOException ex) {
                throw new RuntimeException(ex);
            }
            try {
                conf.load(file);
            } catch (IOException | InvalidConfigurationException ex) {
                throw new RuntimeException(ex);
            }
        } catch (IOException | InvalidConfigurationException e) {
            throw new RuntimeException(e);
        }
    }

    private void save() {
        try {
            conf.save(file);
        } catch (IOException e) {
            throw new RuntimeException(e);
        }
    }

    public List<ShopItem> getItems() {
        List<?> list = conf.getList("items");
        if(list == null) list = new ArrayList<>();
        List<ShopItem> shopItems = new ArrayList<>();
        for (Object o : list) {
            if(o instanceof ShopItem) {
                shopItems.add((ShopItem) o);
            }
        }
        return shopItems;
    }

    public void setItems(List<ShopItem> items) {
        conf.set("items",items);
        save();
    }

    @Nullable
    public ShopItem getItem(int index) {
        List<ShopItem> items = getItems();
        if(items.size()<=index) return null;
        return items.get(index);
    }

    public void setItem(int index, ShopItem item) {
        List<ShopItem> items = getItems();
        items.set(index,item);
        setItems(items);
    }

    public void addItem(ShopItem item) {
        List<ShopItem> items = getItems();
        items.add(item);
        setItems(items);
    }
}
